@@ -7,8 +7,8 @@
 ---------------------------------------------------------------------
 
 local M = {} -- public interface
-M.Version     = '2.9' -- fix version number again
-M.VersionDate = '27jan2021'
+M.Version     = '3.1' -- reset OldHistoryLength if histfile gets set
+M.VersionDate = '20apr2022'
 
 --[[
 Alexander Adler suggests adding four Alternate-Interface functions:
@@ -554,7 +554,8 @@ or on Centos you may need:
 
 =head1 CHANGES
 
-
+ 20220420 3.1 reset OldHistoryLength if histfile gets set
+ 20210418 3.0 pass READLINE_INCDIR and READLINE_LIBDIR to gcc
  20210127 2.9 fix version number again
  20210106 2.8 add set_readline_name() and fix version number
  20200801 2.7 add 5.4
@@ -586,6 +587,7 @@ Alternate Interface functions.
  man readline
  http://www.gnu.org/s/readline
  https://tiswww.case.edu/php/chet/readline/readline.html
+ https://tiswww.cwru.edu/php/chet/readline/history.html#SEC15
  https://tiswww.case.edu/php/chet/readline/readline.html#SEC41
  https://tiswww.case.edu/php/chet/readline/readline.html#SEC45
  /usr/share/readline/inputrc
